@@ -18,25 +18,25 @@
 #include "databaseinterface.h"
 
 #include "elisa_settings.h"
-#include <KConfigCore/KAuthorized>
+#include <KAuthorized>
 #include <KLocalizedString>
 
-#if defined KF5ConfigWidgets_FOUND && KF5ConfigWidgets_FOUND
-#include <KConfigWidgets/KStandardAction>
+#if KF5ConfigWidgets_FOUND
+#include <KStandardAction>
 #endif
 
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
-#include <KXmlGui/KActionCollection>
-#include <KXmlGui/KAboutApplicationDialog>
-#include <KXmlGui/KHelpMenu>
-#include <KXmlGui/KBugReport>
-#include <KXmlGui/KShortcutsDialog>
+#if defined KF5XmlGui_FOUND
+#include <KActionCollection>
+#include <KAboutApplicationDialog>
+#include <KHelpMenu>
+#include <KBugReport>
+#include <KShortcutsDialog>
 #endif
 
 #include <KColorSchemeManager>
-#include <KCoreAddons/KAboutData>
+#include <KAboutData>
 
-#if defined KF5KIO_FOUND && KF5KIO_FOUND
+#if KF5KIO_FOUND
 #include <KIO/OpenFileManagerWindowJob>
 #endif
 
@@ -55,6 +55,8 @@
 #include <QKeyEvent>
 #include <QDebug>
 #include <QFileSystemWatcher>
+#include <QMimeDatabase>
+#include <QMimeType>
 
 #include <memory>
 
@@ -63,19 +65,17 @@ class ElisaApplicationPrivate
 public:
 
     explicit ElisaApplicationPrivate(QObject *parent)
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
         : mCollection(parent)
     #endif
     {
         Q_UNUSED(parent)
     }
 
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     KActionCollection mCollection;
 #endif
 
-    DataTypes::EntryDataList mArguments;
-
     std::unique_ptr<MusicListenersManager> mMusicManager;
 
     std::unique_ptr<MediaPlayList> mMediaPlayList;
@@ -134,7 +134,7 @@ void ElisaApplication::activateColorScheme(const QString &name)
 
 void ElisaApplication::setupActions(const QString &actionName)
 {
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     if (actionName == QLatin1String("file_quit")) {
         auto quitAction = KStandardAction::quit(QCoreApplication::instance(), &QCoreApplication::quit, &d->mCollection);
         d->mCollection.addAction(actionName, quitAction);
@@ -222,17 +222,27 @@ void ElisaApplication::setupActions(const QString &actionName)
 #endif
 }
 
-void ElisaApplication::setArguments(const DataTypes::EntryDataList &newArguments)
+void ElisaApplication::openFiles(const QList<QUrl> &files)
 {
-    if (d->mArguments == newArguments) {
-        return;
+    openFiles(files, QDir::currentPath());
+}
+
+void ElisaApplication::openFiles(const QList<QUrl> &files, const QString &workingDirectory)
+{
+    auto audioFiles = DataTypes::EntryDataList{};
+    const QMimeDatabase mimeDB;
+    for (const auto &file : files) {
+        const QMimeType mime = mimeDB.mimeTypeForUrl(file);
+        if (mime.inherits(QStringLiteral("audio/x-mpegurl"))) {
+            d->mMediaPlayListProxyModel->loadPlayList(file);
+        } else if (mime.name().startsWith(QStringLiteral("audio/"))) {
+            audioFiles.push_back(DataTypes::EntryData{{{DataTypes::ElementTypeRole, ElisaUtils::FileName},
+                            {DataTypes::ResourceRole, file}}, {}, {}});
+        }
     }
-
-    d->mArguments = checkFileListAndMakeAbsolute(newArguments, QDir::currentPath());
-    Q_EMIT argumentsChanged();
-
-    if (!d->mArguments.isEmpty()) {
-        Q_EMIT enqueue(d->mArguments,
+    audioFiles = checkFileListAndMakeAbsolute(audioFiles, workingDirectory);
+    if (!audioFiles.isEmpty()) {
+        Q_EMIT enqueue(audioFiles,
                        ElisaUtils::PlayListEnqueueMode::AppendPlayList,
                        ElisaUtils::PlayListEnqueueTriggerPlay::TriggerPlay);
     }
@@ -247,28 +257,22 @@ void ElisaApplication::activateActionRequested(const QString &actionName, const
 void ElisaApplication::activateRequested(const QStringList &arguments, const QString &workingDirectory)
 {
     if (arguments.size() > 1) {
-        auto realArguments = DataTypes::EntryDataList{};
-
+        QList<QUrl> urls;
         bool isFirst = true;
         for (const auto &oneArgument : arguments) {
             if (isFirst) {
                 isFirst = false;
                 continue;
             }
-
-            realArguments.push_back({{{DataTypes::ElementTypeRole, ElisaUtils::Track},
-                                      {DataTypes::ResourceRole, QUrl::fromUserInput(oneArgument)}}, {}, {}});
+            urls.push_back(QUrl::fromUserInput(oneArgument));
         }
-
-        Q_EMIT enqueue(checkFileListAndMakeAbsolute(realArguments, workingDirectory),
-                       ElisaUtils::PlayListEnqueueMode::AppendPlayList,
-                       ElisaUtils::PlayListEnqueueTriggerPlay::TriggerPlay);
+        openFiles(urls, workingDirectory);
     }
 }
 
 void ElisaApplication::openRequested(const QList<QUrl> &uris)
 {
-    Q_UNUSED(uris)
+    openFiles(uris);
 }
 
 void ElisaApplication::appHelpActivated()
@@ -278,7 +282,7 @@ void ElisaApplication::appHelpActivated()
 
 void ElisaApplication::aboutApplication()
 {
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     static QPointer<QDialog> dialog;
     if (!dialog) {
         dialog = new KAboutApplicationDialog(KAboutData::applicationData(), nullptr);
@@ -290,7 +294,7 @@ void ElisaApplication::aboutApplication()
 
 void ElisaApplication::reportBug()
 {
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     static QPointer<QDialog> dialog;
     if (!dialog) {
         dialog = new KBugReport(KAboutData::applicationData(), nullptr);
@@ -302,7 +306,7 @@ void ElisaApplication::reportBug()
 
 void ElisaApplication::configureShortcuts()
 {
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     KShortcutsDialog dlg(KShortcutsEditor::ApplicationAction, KShortcutsEditor::LetterShortcutsAllowed, nullptr);
     dlg.setModal(true);
     dlg.addCollection(&d->mCollection);
@@ -500,17 +504,11 @@ void ElisaApplication::initializePlayer()
     d->mManageHeaderBar->setIsValidRole(MediaPlayList::IsValidRole);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::currentTrackChanged, d->mManageHeaderBar.get(), &ManageHeaderBar::setCurrentTrack);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::currentTrackDataChanged, d->mManageHeaderBar.get(), &ManageHeaderBar::updateCurrentTrackData);
-
-    if (!d->mArguments.isEmpty()) {
-        Q_EMIT enqueue(d->mArguments,
-                       ElisaUtils::PlayListEnqueueMode::AppendPlayList,
-                       ElisaUtils::PlayListEnqueueTriggerPlay::TriggerPlay);
-    }
 }
 
 QAction * ElisaApplication::action(const QString& name)
 {
-#if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
+#if KF5XmlGui_FOUND
     auto resultAction = d->mCollection.action(name);
 
     if (!resultAction) {
@@ -526,6 +524,12 @@ QAction * ElisaApplication::action(const QString& name)
 #endif
 }
 
+const QString ElisaApplication::actionShortcut(QAction *action) const
+{
+    return action->shortcut().toString(QKeySequence::PortableText);
+}
+
+
 QString ElisaApplication::iconName(const QIcon& icon)
 {
     return icon.name();
@@ -543,30 +547,27 @@ void ElisaApplication::installKeyEventFilter(QObject *object)
 bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
 {
     Q_UNUSED(object)
-
+#if KF5XmlGui_FOUND
     auto *keyEvent = static_cast<QKeyEvent*>(event);
     auto playPauseAction = d->mCollection.action(QStringLiteral("Play-Pause"));
     if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0] == Qt::Key_Space) {
         return true;
     }
-
+#else
+    Q_UNUSED(event)
+#endif
     return false;
 }
 
 void ElisaApplication::showInFolder(QUrl filePath)
 {
-#if defined KF5KIO_FOUND && KF5KIO_FOUND
+#if KF5KIO_FOUND
     KIO::highlightInFileManager({filePath});
 #else
     Q_UNUSED(filePath)
 #endif
 }
 
-const DataTypes::EntryDataList &ElisaApplication::arguments() const
-{
-    return d->mArguments;
-}
-
 MusicListenersManager *ElisaApplication::musicManager() const
 {
     return d->mMusicManager.get();
@@ -624,6 +625,13 @@ bool ElisaApplication::showSystemTrayIcon() const
     return currentConfiguration->showSystemTrayIcon();
 }
 
+bool ElisaApplication::useFavoriteStyleRatings() const
+{
+    auto currentConfiguration = Elisa::ElisaConfiguration::self();
+
+    return currentConfiguration->useFavoriteStyleRatings();
+}
+
 ElisaUtils::PlayListEntryType ElisaApplication::embeddedView() const
 {
     ElisaUtils::PlayListEntryType result = ElisaUtils::Unknown;
