@@ -309,7 +309,7 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
     if (d->mShufflePlayList) {
         const auto newItemsCount = end - start + 1;
         d->mRandomMapping.reserve(rowCount() + newItemsCount);
-        if (rowCount() == 0 || newItemsCount == 1) {
+        if (rowCount() == 0) {
             beginInsertRows(parent, start, end);
             for (int i = 0; i < newItemsCount; ++i) {
                 //QRandomGenerator.bounded(int) is exclusive, thus + 1
@@ -497,9 +497,7 @@ void MediaPlayListProxyModel::enqueue(const DataTypes::EntryDataList &newEntries
     d->mTriggerPlay = triggerPlay;
 
     if (enqueueMode == ElisaUtils::ReplacePlayList) {
-        if (rowCount() == 0) {
-            Q_EMIT hideUndoNotification();
-        } else {
+        if (rowCount() != 0) {
             clearPlayList();
         }
     }
@@ -549,7 +547,7 @@ void MediaPlayListProxyModel::skipPreviousTrack(qint64 position)
     }
 
     if (position > mSeekToBeginningDelay) {
-        emit seek(0);
+        Q_EMIT seek(0);
         return;
     }
 
@@ -685,7 +683,6 @@ void MediaPlayListProxyModel::undoClearPlayList()
     d->mPlayListModel->clearPlayList();
 
     setPersistentState(d->mPersistentSettingsForUndo);
-    Q_EMIT hideUndoNotification();
     Q_EMIT undoClearPlayListPlayer();
 }
 
@@ -816,9 +813,7 @@ void MediaPlayListProxyModel::enqueueDirectory(const QUrl &fileName, ElisaUtils:
     if (!fileName.isLocalFile()) return;
     // clear playlist if required
     if (enqueueMode == ElisaUtils::ReplacePlayList) {
-        if (rowCount() == 0) {
-            Q_EMIT hideUndoNotification();
-        } else {
+        if (rowCount() != 0) {
             clearPlayList();
         }
     }
